@@ -7,22 +7,22 @@ RngStream *RngArray = NULL;
 
 void RngArray_CreateStream(
 	CintCP len,
-	RngStream RngArray[*len])
+	RngStream g[*len])
 {
 	register int i;
 	for (i = 0; i < *len; i++) {
-		RngArray[i] = RngStream_CreateStream("");
+		g[i] = RngStream_CreateStream("");
 	}
 	return;
 } // RngArray_CreateStream
 
 void RngArray_DeleteStream(
 	CintCP len,
-	RngStream RngArray[*len])
+	RngStream g[*len])
 {
 	register int i;
 	for (i = 0; i < *len; i++) {
-		RngStream_DeleteStream(&RngArray[i]);
+		RngStream_DeleteStream(&g[i]);
 	}
 	return;
 } // RngArray_DeleteStream
